.. _user:

User guide
==========

This guide explains how to :ref:`install <installation>` and :ref:`use <usage>` COBYQA.
It also briefly introduce the :ref:`framework <framework>` of the method.
For more details on the Python API of COBYQA, see the :ref:`API reference <api>`.

.. toctree::
    :caption: Getting started
    :maxdepth: 1

    installation
    usage
    releases

.. toctree::
    :caption: Description of the COBYQA method
    :maxdepth: 1

    framework
    subsolvers

.. toctree::
    :hidden:
    :caption: Extras

    ../license
